@@ -277,7 +277,7 @@ class IQContainer:
             values=values.copy()
             for v in exclude:
                 if v in values:
-                    del values[exclude]
+                    del values[v]
         return values
     def _normalize_name(self, name):
         if isinstance(name,tuple):
@@ -442,10 +442,29 @@ class QFrameContainer(IQWidgetContainer, QtWidgets.QFrame):
 class QGroupBoxContainer(IQWidgetContainer, QtWidgets.QGroupBox):
     """An extension of :class:`IQWidgetContainer` for a ``QGroupBox`` Qt base class"""
     def setup(self, caption=None, layout="vbox", no_margins=False, name=None):
-        QWidgetContainer.setup(self,layout=layout,no_margins=no_margins,name=name)
+        super().setup(layout=layout,no_margins=no_margins,name=name)
         if caption is not None:
             self.setTitle(caption)
 
+class QScrollAreaContainer(IQContainer, QtWidgets.QScrollArea):
+    """
+    An extension of :class:`IQWidgetContainer` for a ``QScrollArea`` Qt base class.
+    
+    Due to Qt organization, this container is "intermediate": it contains only a single :class:`QWidgetContainer` widget (named ``"widget"``),
+    which int turn has all of the standard container traits: layout, multiple widgets, etc.
+    """
+    def setup(self, layout="vbox", no_margins=False, name=None):
+        super().setup(name=name)
+        self.setFrameStyle(QtWidgets.QFrame.NoFrame)
+        self.setWidgetResizable(True)
+        self._cont=QWidgetContainer(self)
+        self._cont.setup(layout=layout,no_margins=no_margins,name="widget")
+        self.add_child("widget",self._cont)
+        self.setWidget(self._cont)
+    def clear(self):
+        cont=self.widget()
+        if cont is not None:
+            cont.clear()
 
 
 
@@ -501,4 +520,14 @@ class QTabContainer(IQContainer, QtWidgets.QTabWidget):
     def clear(self):
         for n in list(self._tabs):
             self.remove_tab(n)
-        super().clear()
\ No newline at end of file
+        super().clear()
+    def get_current_name(self):
+        """Get current tab name"""
+        tab=self.currentWidget()
+        for n,w in self._tabs.items():
+            if tab is w:
+                return n
+    def set_by_name(self, name):
+        """Set tab by name"""
+        tab=self.c[name]
+        self.setCurrentIndex(self.indexOf(tab))
\ No newline at end of file
