@@ -1,4 +1,4 @@
-from .base import AndorError, AndorTimeoutError, AndorNotSupportedError
+from .base import AndorError, AndorTimeoutError, AndorFrameTransferError, AndorNotSupportedError
 from . import atcore_lib
 from .atcore_lib import lib, AndorSDK3LibError, feature_types, read_uint12
 
@@ -204,6 +204,7 @@ class AndorSDK3Camera(camera.IBinROICamera, camera.IExposureCamera, camera.IAttr
     """
     Error=AndorError
     TimeoutError=AndorTimeoutError
+    FrameTransferError=AndorFrameTransferError
     _TFrameInfo=TFrameInfo
     _frameinfo_fields=general.make_flat_namedtuple(TFrameInfo,fields={"size":camera.TFrameSize})._fields
     def __init__(self, idx=0):
@@ -244,6 +245,7 @@ class AndorSDK3Camera(camera.IBinROICamera, camera.IExposureCamera, camera.IAttr
         self._opid=libctl.open().opid
         self._update_attributes()
         self._register_events()
+        self.clear_acquisition()
     def close(self):
         """Close connection to the camera"""
         if self.handle is not None:
@@ -328,7 +330,7 @@ class AndorSDK3Camera(camera.IBinROICamera, camera.IExposureCamera, camera.IAttr
 
     def _get_feature(self, name, writable=False):
         """
-        Check if the feature is available and return the corrensponding attribute.
+        Check if the feature is available and return the corresponding attribute.
 
         If ``writable==True``, also check if it's writable.
         """
@@ -455,6 +457,11 @@ class AndorSDK3Camera(camera.IBinROICamera, camera.IExposureCamera, camera.IAttr
         """Enable or disable metadata streaming"""
         self.set_attribute_value("MetadataEnable",enable,error_on_missing=False)
         return self.is_metadata_enabled()
+    def _convert_frame_info(self, info, fmt=None):
+        info=super()._convert_frame_info(info,fmt=fmt)
+        if isinstance(info,np.ndarray) and info[1] is None:
+            info=np.array([info[0]]+[0]*(len(info)-1))
+        return info
     
     ### Frame management ###
     class BufferManager:
@@ -629,7 +636,7 @@ class AndorSDK3Camera(camera.IBinROICamera, camera.IExposureCamera, camera.IAttr
         """
         Choose the camera behavior if buffer overflow is encountered when waiting for a new frame.
 
-        Can be ``"error"`` (raise ``AndorError``), ``"restart"`` (restart the acquisition), or ``"ignore"`` (ignore the overflow, which will cause the wait to time out).
+        Can be ``"error"`` (raise ``AndorFrameTransferError``), ``"restart"`` (restart the acquisition), or ``"ignore"`` (ignore the overflow, which will cause the wait to time out).
         """
         self._overflow_behavior=behavior
 
@@ -740,15 +747,15 @@ class AndorSDK3Camera(camera.IBinROICamera, camera.IExposureCamera, camera.IAttr
         ``(min, max, pstep, sstep, maxbin)`` with, correspondingly, minimal and maximal size,
         position and size step, and the maximal binning.
 
-        Note that the minimal ROI size depends on the current (not just suppled) binning settings.
+        Note that the minimal ROI size depends on the current (not just supplied) binning settings.
         For more accurate results, is it only after setting up the binning.
         """
-        hdet,wdet=self.get_detector_size()
+        wdet,hdet=self.get_detector_size()
         params=[self._get_feature(p) for p in ["AOIWidth","AOIHeight","AOIHBin","AOIVBin"]]
         minp=[p.min for p in params]
         maxp=[p.max for p in params]
-        hlim=camera.TAxisROILimit(minp[0]*hbin,hdet,1,hbin,maxp[2])
-        vlim=camera.TAxisROILimit(minp[1]*vbin,wdet,1,vbin,maxp[3])
+        hlim=camera.TAxisROILimit(minp[0]*hbin,wdet,1,hbin,maxp[2])
+        vlim=camera.TAxisROILimit(minp[1]*vbin,hdet,1,vbin,maxp[3])
         return hlim,vlim
     
     def _check_buffer_overflow(self):
@@ -758,7 +765,7 @@ class AndorSDK3Camera(camera.IBinROICamera, camera.IExposureCamera, camera.IAttr
                 return False
             if self._overflow_behavior=="error":
                 self.stop_acquisition()
-                raise AndorError("buffer overflow")
+                raise self.FrameTransferError("buffer overflow while waiting for a new frame")
             self.start_acquisition()
             return True
         return False
