@@ -1,12 +1,12 @@
-from ...core.devio import SCPI, interface, DeviceError, DeviceBackendError
+from ...core.devio import SCPI, interface, comm_backend
 
 import numpy as np
 import collections
 
 
-class LakeshoreError(DeviceError):
+class LakeshoreError(comm_backend.DeviceError):
     """Generic Lakeshore devices error"""
-class LakeshoreBackendError(LakeshoreError,DeviceBackendError):
+class LakeshoreBackendError(LakeshoreError,comm_backend.DeviceBackendError):
     """Generic Lakeshore backend communication error"""
 
 TLakeshore218AnalogSettings=collections.namedtuple("TLakeshore218AnalogSettings",["bipolar","mode","channel","source","high_value","low_value","man_value"])
@@ -114,7 +114,6 @@ class Lakeshore218(SCPI.SCPIDevice):
         """
         cheader=tuple(self._wap.get_curve_header(index))
         header=[(cv if nv is None else nv) for cv,nv in zip(cheader,[name,serial,fmt,limit,coeff])]
-        print([index]+header)
         self.write("CRVHDR",[index]+header,["int","string","string","int","float","int"])
         return self._wip.get_curve_header(index)
     def get_curve(self, index, trim_zeros=True):
