@@ -19,7 +19,7 @@ from ....core.dataproc import filters
 
 import pyqtgraph
 
-from ....core.gui import QtCore
+from ....core.gui import QtCore, Signal
 import numpy as np
 import contextlib
 import time
@@ -86,9 +86,9 @@ class ImagePlotterCtl(QWidgetContainer):
             self.params.add_spacer(width=20)
             self.params.add_check_box("hlineon","Y  ",value=True).get_value_changed_signal().connect(self._setup_gui_state)
             self.params.add_num_edit("hlinepos",value=0,limiter=(0,None,"coerce","float"),formatter=("float","auto",1,True))
+        self.params.add_button("center_lines","Center lines").get_value_changed_signal().connect(plotter.center_lines)
         self.params.add_check_box("show_linecuts","Show line cuts",value=False).get_value_changed_signal().connect(self._setup_gui_state)
         self.params.add_num_edit("linecut_width",value=1,limiter=(1,None,"coerce","int"),formatter="int",label="Line cut width:")
-        self.params.add_button("center_lines","Center lines").get_value_changed_signal().connect(plotter.center_lines)
         self.params.contained_value_changed.connect(lambda n: self.plotter.update_image(update_controls=(n=="normalize"),do_redraw=True),QtCore.Qt.DirectConnection)
         self.params.add_spacer(10)
         self.params.add_toggle_button("update_image","Updating",value=True).get_value_changed_signal().connect(plotter._set_image_update)
@@ -216,7 +216,7 @@ class ImagePlotter(QLayoutManagedWidget):
         super().setup(layout="vbox",no_margins=True)
         self.name=name
         self.single_armed=False
-        self.single_acquired=False
+        self.new_image_set=False
         self.img=np.zeros(img_size)
         self.do_image_update=True
         self.xbin=1
@@ -230,7 +230,7 @@ class ImagePlotter(QLayoutManagedWidget):
             self.setMinimumSize(QtCore.QSize(*min_size))
         self.image_window=pyqtgraph.ImageView(self,imageItem=ImageItem())
         self.add_to_layout(self.image_window)
-        self.set_colormap("hot_sat")
+        self.set_colormap("gray_sat")
         self.image_window.ui.roiBtn.hide()
         self.image_window.ui.menuBtn.hide()
         self.image_window.getView().setMenuEnabled(False)
@@ -308,7 +308,7 @@ class ImagePlotter(QLayoutManagedWidget):
         """
         Setup colormap.
 
-        Can be name of one built-in colormaps (``"gray"``, ``"gray_sat"``, ``"hot"``, ``"hot_sat"``),
+        Can be name of one built-in colormaps (``"gray"``, ``"gray_sat"``, ``"gray_doublesat"``, ``"hot"``, ``"hot_sat"``),
         one of PyQtGraph built-in cmaps (e.g., ``"flame"`` or ``"bipolar"``),
         a list specifying PyQtGraph colormap or a :class:`pyqtgraph.ColorMap` instance.
         """
@@ -346,7 +346,7 @@ class ImagePlotter(QLayoutManagedWidget):
                 raise ValueError("only 2D images or 3D images with 3 or 4 color channels are allowed; got image with the shape {}".format(img.shape))
             self.img=img
             self.single_armed=False
-            self.single_acquired=True
+            self.new_image_set=True
     def arm_single(self):
         """Arm the single-image trigger"""
         self.single_armed=True
@@ -489,11 +489,11 @@ class ImagePlotter(QLayoutManagedWidget):
         return True
     # Update image plot
     @controller.exsafe
-    def update_image(self, update_controls=False, do_redraw=False, only_new_image=True):
+    def update_image(self, update_controls=True, do_redraw=False, only_new_image=True):
         """
         Update displayed image.
 
-        If ``update_controls==True``, update control values (such as image min/max values and line positions).
+        If ``update_controls==True``, update control values (such as image min/max values and line positions); otherwise, keep the current values.
         If ``do_redraw==True``, force update regardless of the ``"update_image"`` button state; otherwise, update only if it is enabled.
         If ``only_new_image==True`` and the image hasn't changed since the last call to ``update_image``, skip redraw (however, if ``do_redraw==True``, force redrawing regardless).
         """
@@ -505,11 +505,9 @@ class ImagePlotter(QLayoutManagedWidget):
         with self._while_updating():
             values=self._get_values()
             if not do_redraw:
-                if not (values.v["update_image"] or self.single_acquired):
+                if not self.new_image_set and (only_new_image or not self.do_image_update):
                     return
-                if only_new_image and not self.single_acquired:
-                    return
-                self.single_acquired=False
+            self.new_image_set=False
             draw_img=self.img
             if self.xbin>1:
                 draw_img=filters.decimate(draw_img,self.xbin,dec=self.dec,axis=0)
