@@ -128,11 +128,13 @@ class GenericCameraThread(device_thread.DeviceThread):
         except ValueError:
             pass
         self.v["parameters"]=None
+        self._reset_frame_counters()
+        self.v["frames/last_frame"]=None
         super().close_device()
 
     
     def _set_acquisition_status(self, status, text=None):
-        status_names={"stopped":"Stopped", "setup":"Settings up...", "acquiring":"In progress", "cleanup":"Cleaning up..."}
+        status_names={"stopped":"Stopped", "setup":"Setting up...", "acquiring":"In progress", "cleanup":"Cleaning up..."}
         self.update_status("acquisition",status,text or status_names.get(status))
     def setup_acquisition(self, *args, force_setup=False, **kwargs):
         status=self.sv["status/acquisition"]
@@ -287,10 +289,11 @@ class GenericCameraThread(device_thread.DeviceThread):
             self.v["frames/read"]+=nread
             self.v["frames/buffer_filled"]=rng[1]-rng[0]
             self.v["frames/last_idx"]=rng[1]-1
-            msg=self.frames_src.build_message(frames,indices,infos,source="camera",metainfo=self._get_metainfo(frames,indices,infos),sn=self.name)
-            self.send_multicast("any","frames/new",msg)
             nsent=len(frames)
-            self.v["frames/last_frame"]=frames[-1] if frames[-1].ndim==2 else frames[-1][-1]
+            if frames:
+                msg=self.frames_src.build_message(frames,indices,infos,source="camera",metainfo=self._get_metainfo(frames,indices,infos),sn=self.name)
+                self.send_multicast("any","frames/new",msg)
+                self.v["frames/last_frame"]=frames[-1] if frames[-1].ndim==2 else frames[-1][-1]
         return nsent
 
     def add_acq_loop(self, name, loop, finalize=None):
@@ -373,7 +376,7 @@ class GenericCameraThread(device_thread.DeviceThread):
 
         State can be ``"stopped"`` (acquisition stopped) or ``"acquiring"`` (acquisition is in progress)
         """
-        self.wait_for_variable("status/acquisition",state)
+        self.sync_variable("status/acquisition",state)
     def wait_for_next_frame(self, n=1, start=None, timeout=None):
         """
         Wait until `n` frames have been acquired starting from the `start` (current moment by default).
@@ -384,5 +387,5 @@ class GenericCameraThread(device_thread.DeviceThread):
         """
         if start is None:
             start=self.v["frames/last_idx"]
-        self.wait_for_variable("frames/last_idx", lambda idx: idx>=start+n, timeout=timeout)
+        self.sync_variable("frames/last_idx", lambda idx: idx>=start+n, timeout=timeout)
         return self.v["frames/last_frame"]
\ No newline at end of file
